@@ -6,7 +6,7 @@
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -16,24 +16,24 @@
  */
 package org.apache.commons.codec.digest;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
 
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
-public class B64Test {
+class B64Test {
 
     @Test
-    public void testB64T() {
-        assertNotNull(new B64()); // for the 100% code coverage :)
-        assertEquals(64, B64.B64T.length());
-    }
-
-    @Test
-    public void testB64from24bit() {
-        StringBuilder buffer = new StringBuilder("");
+    void testB64from24bit() {
+        final StringBuilder buffer = new StringBuilder("");
         B64.b64from24bit((byte) 8, (byte) 16, (byte) 64, 2, buffer);
         B64.b64from24bit((byte) 7, (byte) 77, (byte) 120, 4, buffer);
         assertEquals("./spo/", buffer.toString());
     }
+
+    @Test
+    void testB64T() {
+        assertNotNull(new B64()); // for the 100% code coverage :)
+        assertEquals(64, B64.B64T_ARRAY.length);
+    }
 }
